package HTML::ColorKeywords;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;

@ISA = qw(Exporter AutoLoader);
@EXPORT = qw(do);
$VERSION = '0.1';

sub new {
    my $class = shift;
    my $self = {};
    my %param = @_;
    @{$self->{colors}} =
	("#ffff66", "#A0ffff", "#99ff99", "#ff9999", "#ff66ff",
	 "#880000", "#00aa00", "#886800", "#004699", "#990099"); 
    for (keys %param) { $self->{lc($_)} = $param{$_} } 
    _set_regex($self, $param{keys}) if defined $param{keys};
    return bless $self, $class;
}

sub do {
    my ($self, %args) = @_;
    $self->_set_regex($args{keys}) if defined $args{keys};
    my $sp = $args{string};
    return if not defined $sp;
    my @frag = split(/(<.*?>)/, $$sp);
    foreach (@frag) {
	next if (/^<.*?>$/);
	s!($self->{keypat})!"<span style=\"background-color:".
	    $self->{colors}->[$self->{key2no}{$1} % @{$self->{colors}}].
	    "\">$1</span>"!gie;
    }
    $$sp = join("", @frag);
}

sub _set_regex {
    my ($self, $keys) = @_;
    $self->{keypat} = join("|", map {"\Q".$_."\E"} @$keys);
    %{$self->{key2no}} = map {$keys->[$_]=>$_} (0..$#{$keys});
}

1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

HTML::ColorKeywords - Highliting(Coloring) keywords in web pages

=head1 SYNOPSIS

  use HTML::ColorKeywords;
  {
      my $c = HTML::ColorKeywords->new(keys => ['abc','a','b']);
      my $s = qq(_<a href="/">ac</a>_bc_<b>abc</b>_);
      $c->do(string => \$s);
      print "$s\n";
  }
  {
      my $c = HTML::ColorKeywords->new();
      my $s = "acebecddcbcaed";
      my @k = ('ac', 'bc');
      $c->do(keys => \@k, string => \$s);
      print "$s\n";
  }
  {
      my $c = HTML::ColorKeywords->new(colors => ['red', 'blue']);
      my $s = "edhjbicopan";
      $c->do(keys => ['a','b','c'], string => \$s);
      print "$s\n";
  }

=head1 DESCRIPTION

HTML::ColorKeywords emphasizes keywords in web pages.
It is easy to use, and useful, especially for search-result pages.

INPUT: 
Keywords=('abc','ghi',...), String='xyzabcdef'

RESULT(Emphasized): 
'xyz<span style="background-color:#A0ffff">abc</span>def'

=head1 AUTHOR

YAMASHITA Tatsuo, tatsuo+perl at gmail.com

=head1 SEE ALSO

perl(1).

=cut
